@@ -936,19 +936,15 @@ class Builder(Update):
         # asterisk = self.color_print.bold("*")
         # ebuild_wrong = TextState.Colors.RED
         ebuild_color = TextState.Colors.GREEN
-        binary_color = TextState.Colors.PURPLE
+        binary_color = TextState.Colors.LIGHT_GREEN
         output_package_list = ", ".join(
             self.color_print.foreground(binary_color)(str(x))
             if x['binary'] else
             self.color_print.foreground(ebuild_color)(str(x))
             for x in package_list if x['PN'] != drv_name
         )
-        wrong_package = any(not x['binary'] and x['PN'] != drv_name
-                            for x in package_list)
-        if wrong_package:
-            self.printERROR(_("Depends %s") % output_package_list)
-        else:
-            self.printSUCCESS(_("Depends %s") % output_package_list)
+        
+        self.printSUCCESS(_("Depends %s") % output_package_list)
 
     def fetch_drivers(self, builder_path, builder_distdir, builder_pkgdir):
         """
